@@ -576,9 +576,14 @@ pkgbib <- function(pkg) {
     }
     cat(b, sep = "\n", file = "packages.bib", append = TRUE)
 }
-pkg <- function(pkg)
+
+pkg <- function(pkg) {
+    vrs <- try(pkgversion(pkg))
+    if (inherits(vrs, "try-error")) return(NA)
     paste("\\\\pkg{", pkg, "} \\\\citep[version~",
-          pkgversion(pkg), ",][]{pkg:", pkg, "}", sep = "")
+          vrs, ",][]{pkg:", pkg, "}", sep = "")
+}
+
 pkg("mlt")
 pkg("tram")
 pkg("SparseGrid")
